"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const Drawer_1 = tslib_1.__importDefault(require("@material-ui/core/Drawer"));
const Typography_1 = tslib_1.__importDefault(require("@material-ui/core/Typography"));
const react_1 = tslib_1.__importStar(require("react"));
const comments_1 = require("../context/comments");
const hooks_1 = require("../hooks");
const comment_1 = require("./comment");
const CreateComment_1 = require("./comment/CreateComment");
const _1 = require("./");
const THUMBNAIL_PADDING = 16;
const THUMBNAIL_NAME = 'Thumbnail';
const PAGE_PADDING = 8;
const PAGE_NAME = 'Page';
exports.DocumentViewerLayout = (props) => {
    const viewerState = hooks_1.useViewerState();
    const localization = hooks_1.useLocalization();
    const thumbnailPadding = props.thumbnailPadding != null ? props.thumbnailPadding : THUMBNAIL_PADDING;
    const pagePadding = props.pagePadding != null ? props.pagePadding : PAGE_PADDING;
    const api = hooks_1.useDocumentViewerApi();
    const { documentData } = hooks_1.useDocumentData();
    const [createCommentValue, setCreateCommentValue] = react_1.useState('');
    const commentsContainerRef = react_1.useRef();
    const commentState = hooks_1.useCommentState();
    const handleKeyUp = react_1.useCallback((ev) => {
        if (ev.key !== 'Escape') {
            return;
        }
        if (viewerState.isPlacingCommentMarker) {
            return viewerState.updateState({ isPlacingCommentMarker: false });
        }
        if (viewerState.isCreateCommentActive) {
            viewerState.updateState({ isCreateCommentActive: false });
        }
        commentState.setActiveComment(undefined);
        setCreateCommentValue('');
    }, [commentState, viewerState]);
    react_1.useEffect(() => {
        document.addEventListener('keyup', handleKeyUp);
        return () => document.removeEventListener('keyup', handleKeyUp);
    }, [handleKeyUp]);
    const scrollToImage = react_1.useCallback(({ containerId, index, itemName, padding, smoothScroll }) => {
        const container = document.getElementById(containerId);
        const item = document.querySelector(`.${itemName}`);
        if (container && container.scrollTo && item) {
            container.scrollTo({
                top: (item.clientHeight + padding * 4) * (index - 1),
                behavior: smoothScroll ? 'smooth' : 'auto',
            });
        }
    }, []);
    const scrollTo = react_1.useCallback((index, smoothScroll = true) => {
        scrollToImage({
            containerId: 'sn-document-viewer-pages',
            itemName: PAGE_NAME,
            padding: pagePadding,
            index,
            smoothScroll,
        });
        scrollToImage({
            containerId: 'sn-document-viewer-thumbnails',
            itemName: THUMBNAIL_NAME,
            padding: thumbnailPadding,
            index,
            smoothScroll,
        });
    }, [pagePadding, scrollToImage, thumbnailPadding]);
    react_1.useEffect(() => {
        const observer = viewerState.onPageChange.subscribe((p) => {
            scrollTo(p);
        });
        return () => observer.dispose();
    }, [scrollTo, viewerState.onPageChange]);
    const createComment = react_1.useCallback((text) => {
        if (!commentState.draft || !viewerState.activePages[0] || !viewerState.activePages[0]) {
            return;
        }
        api.commentActions.addPreviewComment({
            document: documentData,
            comment: Object.assign(Object.assign({}, commentState.draft), { text, page: viewerState.activePages[0] }),
            abortController: new AbortController(),
        });
        viewerState.updateState({ isPlacingCommentMarker: false });
    }, [api.commentActions, commentState.draft, documentData, viewerState]);
    return (react_1.default.createElement("div", { style: {
            width: '100%',
            height: '100%',
            display: 'flex',
            flexDirection: 'column',
        } },
        props.children,
        react_1.default.createElement("div", { style: {
                display: 'flex',
                height: '100%',
                width: '100%',
                overflow: 'hidden',
                zIndex: 0,
                position: 'relative',
            } },
            react_1.default.createElement(Drawer_1.default, { variant: 'persistent', open: viewerState.showThumbnails, anchor: "left", SlideProps: props.drawerSlideProps, PaperProps: {
                    style: {
                        position: 'relative',
                        width: viewerState.showThumbnails ? '200px' : 0,
                        height: '100%',
                        overflow: 'hidden',
                    },
                } },
                react_1.default.createElement(_1.PageList, { showWidgets: false, style: { minWidth: 200, marginRight: '-16px', paddingRight: 0 }, id: "sn-document-viewer-thumbnails", zoomMode: "fit", fitRelativeZoomLevel: 0, zoomLevel: 1, onPageClick: (_ev, index) => scrollTo(index), elementName: THUMBNAIL_NAME, images: "thumbnail", tolerance: 0, padding: thumbnailPadding, activePage: viewerState.activePages[0] })),
            react_1.default.createElement(_1.PageList, { showWidgets: true, id: "sn-document-viewer-pages", zoomMode: viewerState.zoomMode, zoomLevel: viewerState.customZoomLevel, fitRelativeZoomLevel: viewerState.fitRelativeZoomLevel, onPageClick: (_ev, index) => scrollTo(index), elementName: PAGE_NAME, images: "preview", tolerance: 0, padding: pagePadding, activePage: viewerState.activePages[0] }),
            react_1.default.createElement(Drawer_1.default, { variant: 'persistent', open: viewerState.showComments, anchor: "right", SlideProps: props.drawerSlideProps, PaperProps: {
                    style: {
                        position: 'relative',
                        width: viewerState.showComments ? '340px' : 0,
                        height: '100%',
                        overflow: 'hidden',
                    },
                } },
                react_1.default.createElement(comments_1.CommentsContextProvider, { page: viewerState.activePages[0], images: "preview" },
                    react_1.default.createElement(_1.CommentsContainer, { ref: commentsContainerRef, style: { display: 'flex', flexFlow: 'column' } },
                        react_1.default.createElement(Typography_1.default, { variant: "h4" }, localization.commentSideBarTitle),
                        react_1.default.createElement(CreateComment_1.CreateComment, { isActive: viewerState.isCreateCommentActive, handleIsActive: (isActive) => viewerState.updateState({ isCreateCommentActive: isActive }), localization: localization, createComment: createComment, inputValue: createCommentValue, handleInputValueChange: (value) => setCreateCommentValue(value) }),
                        react_1.default.createElement(comments_1.CommentsContext.Consumer, null, (commentsContext) => commentsContext.comments.map((comment) => react_1.default.createElement(comment_1.Comment, { key: comment.id, comment: comment })))))))));
};
//# sourceMappingURL=DocumentViewerLayout.js.map