"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const client_utils_1 = require("@sensenet/client-utils");
const Grid_1 = tslib_1.__importDefault(require("@material-ui/core/Grid"));
const react_1 = tslib_1.__importStar(require("react"));
const comments_1 = require("../context/comments");
const hooks_1 = require("../hooks");
const services_1 = require("../services");
const _1 = require("./");
exports.PageList = (props) => {
    const [marginTop, setMarginTop] = react_1.useState(0);
    const [marginBottom, setMarginBottom] = react_1.useState(0);
    const [visiblePages, setVisiblePages] = react_1.useState([]);
    const [scrollState, setScrollState] = react_1.useState(0);
    const viewportElement = react_1.useRef();
    const viewerState = hooks_1.useViewerState();
    const [resizeToken, setResizeToken] = react_1.useState(0);
    const [viewport, setViewport] = react_1.useState({ width: 0, height: 0 });
    const pages = hooks_1.usePreviewImages();
    const requestResize = react_1.useCallback(client_utils_1.debounce(() => {
        setResizeToken(Math.random());
    }, 100), []);
    const onScroll = react_1.useCallback(() => {
        requestResize();
        setScrollState((viewportElement.current && viewportElement.current.scrollTop) || 0);
    }, [requestResize]);
    react_1.useEffect(() => {
        const currentViewport = viewportElement.current;
        if (currentViewport) {
            currentViewport.addEventListener('scroll', onScroll);
        }
        return () => currentViewport && currentViewport.removeEventListener('scroll', onScroll);
    }, [onScroll, viewportElement]);
    react_1.useEffect(() => {
        window.addEventListener('resize', requestResize);
        return () => window.removeEventListener('resize', requestResize);
    }, [requestResize]);
    react_1.useEffect(() => {
        if (viewportElement && viewportElement.current) {
            setViewport({
                height: viewportElement.current.clientHeight - props.padding * 2,
                width: viewportElement.current.clientWidth - props.padding * 2,
            });
        }
    }, [props.padding, resizeToken, viewportElement]);
    react_1.useEffect(() => {
        if (!pages.imageData.length) {
            return;
        }
        let defaultWidth;
        let defaultHeight;
        const _visiblePages = pages.imageData.map((p) => {
            if ((p && !defaultWidth) || !defaultHeight) {
                ;
                [defaultWidth, defaultHeight] = [p.Width, p.Height];
            }
            if (!p.Width || !p.Height) {
                ;
                [p.Width, p.Height] = [defaultWidth, defaultHeight];
            }
            const relativeSize = services_1.ImageUtil.getImageSize({
                width: viewport.width,
                height: viewport.height,
            }, {
                width: p.Width,
                height: p.Height,
                rotation: (p.Attributes && p.Attributes.degree) || 0,
            }, props.zoomMode, props.zoomLevel, props.fitRelativeZoomLevel);
            return Object.assign(Object.assign({}, p), { Width: relativeSize.width, Height: relativeSize.height });
        });
        let _marginTop = 0;
        let _pagesToSkip = 0;
        while (_visiblePages[_pagesToSkip] &&
            _marginTop + _visiblePages[_pagesToSkip].Height + props.tolerance < scrollState) {
            _marginTop += _visiblePages[_pagesToSkip].Height + props.padding * 2;
            _pagesToSkip++;
        }
        let _pagesToTake = 1;
        let _pagesHeight = 0;
        while (_visiblePages[_pagesToSkip + _pagesToTake] && _pagesHeight < viewport.height + props.tolerance) {
            _pagesHeight += _visiblePages[_pagesToSkip + _pagesToTake].Height + props.padding * 2;
            _pagesToTake++;
        }
        let _marginBottom = 0;
        for (let i = _pagesToSkip + _pagesToTake - 1; i < _visiblePages.length - 1; i++) {
            _marginBottom += _visiblePages[i].Height + props.padding * 2;
        }
        setMarginTop(_marginTop);
        setMarginBottom(_marginBottom);
        const newVisiblePages = _visiblePages.slice(_pagesToSkip, _pagesToSkip + _pagesToTake);
        setVisiblePages(newVisiblePages);
        // eslint-disable-next-line react-hooks/exhaustive-deps
    }, [
        pages.imageData,
        props.fitRelativeZoomLevel,
        props.padding,
        props.tolerance,
        props.zoomLevel,
        props.zoomMode,
        scrollState,
        viewerState.activePages,
        viewport.height,
        viewport.width,
    ]);
    const updateScrollState = react_1.useCallback(client_utils_1.debounce(() => {
        if (props.images === 'preview')
            viewerState.updateState({ activePages: [(visiblePages[0] && visiblePages[0].Index) || 1] });
    }, 100), [viewerState, visiblePages]);
    react_1.useEffect(updateScrollState, [scrollState]);
    return (react_1.default.createElement(Grid_1.default, { item: true, style: Object.assign(Object.assign({}, props.style), { flexGrow: 1, flexShrink: 1, overflow: 'auto', height: '100%' }), id: props.id, innerRef: viewportElement },
        react_1.default.createElement("div", { style: {
                display: 'flex',
                flexDirection: 'column',
                justifyContent: 'center',
                alignItems: 'center',
                paddingTop: marginTop || 0,
                paddingBottom: marginBottom || 0,
            } }, visiblePages.map((page) => (react_1.default.createElement(comments_1.CommentsContextProvider, { page: page.Index, key: page.Index, images: props.images },
            react_1.default.createElement(_1.Page, { showWidgets: props.showWidgets, viewportWidth: viewport.width, viewportHeight: viewport.height, imageIndex: page.Index, onClick: (ev) => props.onPageClick(ev, page.Index), zoomMode: props.zoomMode, zoomLevel: props.zoomLevel, fitRelativeZoomLevel: props.fitRelativeZoomLevel, elementName: props.elementName, image: props.images, margin: props.padding })))))));
};
//# sourceMappingURL=PageList.js.map