import { Annotation, Shape, Shapes } from '@sensenet/client-core';
import React from 'react';
import { ZoomMode } from '../../models/viewer-state';
import { Dimensions } from '../../services';
/**
 * Defined the component's own properties
 */
export interface ShapeProps<T extends Shape> {
    shape: T;
    shapeType: keyof Shapes;
    canEdit: boolean;
    zoomRatio: number;
    additionalOffset?: Dimensions;
    zoomMode: ZoomMode;
    customZoomLevel: number;
    updateShapeData: (shapeType: keyof Shapes, guid: string, shape: T) => void;
    removeShape: (shapeType: keyof Shapes, guid: string) => void;
}
/**
 * Class for displaying Shapes on a document page
 */
declare abstract class ShapeComponent<T extends Shape = Shape> extends React.Component<ShapeProps<T>> {
    /** the component state */
    state: {
        focused: boolean;
        onResized: any;
        onBlur: any;
        onDragStart: any;
        handleKeyPress: any;
        onFocus: any;
    };
    /** The type of the shape instance */
    protected abstract shapeType: keyof Shapes;
    /**
     * Method that returns the shape dimensions as CSS properties
     * @param shape the shape instance
     * @param offsetX optional X offset
     * @param offsetY optional Y offset
     */
    protected getShapeDimensions(shape: Shape, offsetX?: number, offsetY?: number): React.CSSProperties;
    /** event that will be triggered on resize */
    protected onResized(ev: React.MouseEvent<HTMLElement>): void;
    /** onDragStart event handler for the Shape instance */
    protected onDragStart(ev: React.DragEvent<HTMLElement>): void;
    /** abstract method for shape rendering */
    abstract renderShape(): JSX.Element;
    /** onKeyPress event handler for deleting shapes */
    protected handleKeyPress(ev: React.KeyboardEvent<HTMLDivElement>): void;
    /** onFocus event handler that updates the 'focused' property */
    onFocus(): void;
    /** onBlur event handler that updates the 'focused' property */
    onBlur(ev: React.FocusEvent<HTMLDivElement>): void;
    /**
     * renders the component
     */
    render(): JSX.Element;
}
export declare class ShapeRedaction extends ShapeComponent {
    /** type of the Shape */
    readonly shapeType = "redactions";
    /** renders the Shape component */
    renderShape(): JSX.Element;
}
export declare class ShapeAnnotation extends ShapeComponent<Annotation> {
    /** type of the Shape */
    readonly shapeType = "annotations";
    /** keypress handler for to stop event bubbling and shape deletion */
    protected handleKeyPress(_ev: React.KeyboardEvent<HTMLDivElement>): void;
    /** onBlur handler for updating inner text */
    onBlur(ev: React.FocusEvent<HTMLDivElement>): void;
    /** renders the Shape component */
    renderShape(): JSX.Element;
}
export declare class ShapeHighlight extends ShapeComponent {
    /** type of the Shape */
    readonly shapeType = "highlights";
    /** renders the Highlight shape component */
    renderShape(): JSX.Element;
}
export {};
//# sourceMappingURL=Shape.d.ts.map