"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const react_1 = tslib_1.__importStar(require("react"));
const hooks_1 = require("../../hooks");
const Shape_1 = require("./Shape");
const style_1 = require("./style");
/**
 * Page widget component for displaying shapes on a page
 */
exports.ShapesWidget = (props) => {
    const permissions = hooks_1.useDocumentPermissions();
    const viewerState = hooks_1.useViewerState();
    const { documentData, updateDocumentData } = hooks_1.useDocumentData();
    const comments = hooks_1.useComments();
    const commentState = hooks_1.useCommentState();
    const [visibleShapes, setVisibleShapes] = react_1.useState({
        redactions: documentData.shapes.redactions.filter((r) => r.imageIndex === props.page.Index),
        highlights: documentData.shapes.highlights.filter((r) => r.imageIndex === props.page.Index),
        annotations: documentData.shapes.annotations.filter((r) => r.imageIndex === props.page.Index),
    });
    react_1.useEffect(() => {
        setVisibleShapes({
            redactions: documentData.shapes.redactions.filter((r) => r.imageIndex === props.page.Index),
            highlights: documentData.shapes.highlights.filter((r) => r.imageIndex === props.page.Index),
            annotations: documentData.shapes.annotations.filter((r) => r.imageIndex === props.page.Index),
        });
    }, [
        documentData.shapes.annotations,
        documentData.shapes.highlights,
        documentData.shapes.redactions,
        props.page.Index,
    ]);
    const removeShape = react_1.useCallback((shapeType, guid) => {
        ;
        documentData.shapes[shapeType] = documentData.shapes[shapeType].filter((s) => s.guid !== guid);
        updateDocumentData(documentData);
        viewerState.updateState({ hasChanges: true });
    }, [documentData, updateDocumentData, viewerState]);
    const updateShapeData = react_1.useCallback((shapeType, guid, shapeChange) => {
        ;
        documentData.shapes[shapeType] = documentData.shapes[shapeType].map((s) => {
            if (s.guid === guid) {
                return Object.assign(Object.assign({}, s), shapeChange);
            }
            return s;
        });
        viewerState.updateState({ hasChanges: true });
        updateDocumentData(documentData);
    }, [documentData, updateDocumentData, viewerState]);
    const onDrop = react_1.useCallback((ev) => {
        if (permissions.canEdit) {
            ev.preventDefault();
            const shapeData = JSON.parse(ev.dataTransfer.getData('shape'));
            const boundingBox = ev.currentTarget.getBoundingClientRect();
            updateShapeData(shapeData.type, shapeData.shape.guid, Object.assign(Object.assign({}, shapeData.shape), { imageIndex: props.page.Index, x: (ev.clientX - boundingBox.left - shapeData.offset.width) * (1 / props.zoomRatio), y: (ev.clientY - boundingBox.top - shapeData.offset.height) * (1 / props.zoomRatio) }));
        }
    }, [permissions.canEdit, props.page.Index, props.zoomRatio, updateShapeData]);
    return (react_1.default.createElement("div", { style: {
            position: 'absolute',
            top: 0,
            left: 0,
            width: '100%',
            height: '100%',
            zIndex: 1,
        }, onDrop: onDrop, onDragOver: (ev) => ev.preventDefault() },
        viewerState.showComments &&
            [...comments.comments, ...(commentState.draft ? [commentState.draft] : [])].map((marker) => (react_1.default.createElement(style_1.CommentMarker, { onClick: () => commentState.setActiveComment(marker.id), isSelected: marker.id === commentState.activeCommentId, zoomRatio: props.zoomRatio, marker: marker, key: marker.id }))),
        react_1.default.createElement("div", null,
            permissions.canHideRedaction &&
                viewerState.showRedaction &&
                visibleShapes.redactions.map((redaction, index) => {
                    return (react_1.default.createElement(Shape_1.ShapeRedaction, { customZoomLevel: viewerState.customZoomLevel, updateShapeData: updateShapeData, removeShape: removeShape, zoomMode: viewerState.zoomMode, shapeType: "redactions", shape: redaction, canEdit: permissions.canEdit, zoomRatio: props.zoomRatio, key: index }));
                }),
            viewerState.showShapes &&
                visibleShapes.annotations.map((annotation, index) => {
                    return (react_1.default.createElement(Shape_1.ShapeAnnotation, { customZoomLevel: viewerState.customZoomLevel, updateShapeData: updateShapeData, removeShape: removeShape, zoomMode: viewerState.zoomMode, shapeType: "annotations", shape: annotation, canEdit: permissions.canEdit, zoomRatio: props.zoomRatio, key: index }));
                }),
            viewerState.showShapes &&
                visibleShapes.highlights.map((highlight, index) => {
                    return (react_1.default.createElement(Shape_1.ShapeHighlight, { customZoomLevel: viewerState.customZoomLevel, updateShapeData: updateShapeData, removeShape: removeShape, zoomMode: viewerState.zoomMode, shapeType: "highlights", shape: highlight, canEdit: permissions.canEdit, zoomRatio: props.zoomRatio, key: index }));
                }))));
};
//# sourceMappingURL=Shapes.js.map