"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const client_utils_1 = require("@sensenet/client-utils");
const hooks_react_1 = require("@sensenet/hooks-react");
const react_1 = tslib_1.__importStar(require("react"));
const uuid_1 = require("uuid");
/**
 * Adds a globally unique ID to the shape
 */
const addGuidToShape = (shape) => {
    shape.guid = uuid_1.v1();
    return shape;
};
/**
 * Concatenates avatar url with host
 * @param {DocumentData} documentData
 */
function changeCreatedByUrlToCurrent(documentData) {
    return (comment) => {
        return Object.assign(Object.assign({}, comment), { createdBy: Object.assign(Object.assign({}, comment.createdBy), { avatarUrl: `${documentData.hostName}${comment.createdBy.avatarUrl}` }) });
    };
}
exports.DocumentViewerApiSettingsContext = react_1.default.createContext({
    canEditDocument: () => tslib_1.__awaiter(void 0, void 0, void 0, function* () { return false; }),
    canHideRedaction: () => tslib_1.__awaiter(void 0, void 0, void 0, function* () { return false; }),
    canHideWatermark: () => tslib_1.__awaiter(void 0, void 0, void 0, function* () { return false; }),
    commentActions: {
        addPreviewComment: ({ comment }) => tslib_1.__awaiter(void 0, void 0, void 0, function* () { return (Object.assign({}, comment)); }),
        deletePreviewComment: () => tslib_1.__awaiter(void 0, void 0, void 0, function* () { return ({ modified: false }); }),
        getPreviewComments: () => tslib_1.__awaiter(void 0, void 0, void 0, function* () { return []; }),
    },
    getDocumentData: () => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
        return ({
            documentName: 'example',
            documentType: '',
            fileSizekB: 3,
            hostName: '',
            idOrPath: 1,
            pageAttributes: [],
            pageCount: 0,
            shapes: { annotations: [], highlights: [], redactions: [] },
        });
    }),
    getExistingPreviewImages: () => tslib_1.__awaiter(void 0, void 0, void 0, function* () { return []; }),
    isPreviewAvailable: () => tslib_1.__awaiter(void 0, void 0, void 0, function* () { return ({ Height: 0, Width: 0, Index: 0, Attributes: { degree: 0 } }); }),
    regeneratePreviews: () => tslib_1.__awaiter(void 0, void 0, void 0, function* () { return undefined; }),
    saveChanges: () => tslib_1.__awaiter(void 0, void 0, void 0, function* () { return undefined; }),
});
exports.createDefaultApiSettings = (repo) => ({
    regeneratePreviews: ({ document, abortController }) => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
        repo.preview.regenerate({ idOrPath: document.idOrPath, abortController });
    }),
    saveChanges: ({ document, pages, abortController }) => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
        const reqBody = {
            Shapes: JSON.stringify([
                { redactions: document.shapes.redactions },
                { highlights: document.shapes.highlights },
                { annotations: document.shapes.annotations },
            ]),
            PageAttributes: JSON.stringify(pages
                .map((p) => (p.Attributes && p.Attributes.degree && { pageNum: p.Index, options: p.Attributes }) || undefined)
                .filter((p) => p !== undefined)),
        };
        yield repo.patch({
            idOrPath: document.idOrPath,
            content: reqBody,
            requestInit: {
                signal: abortController.signal,
            },
        });
    }),
    getDocumentData: (settings) => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
        const documentData = (yield repo.load({
            idOrPath: settings.idOrPath,
            oDataOptions: {
                select: 'all',
            },
        })).d;
        return {
            idOrPath: settings.idOrPath,
            hostName: repo.configuration.repositoryUrl,
            fileSizekB: documentData.Size,
            pageCount: client_utils_1.toNumber(documentData.PageCount, -1),
            documentName: documentData.DisplayName || '',
            documentType: documentData.Type || 'File',
            shapes: (documentData.Shapes && {
                redactions: JSON.parse(documentData.Shapes)[0].redactions.map((a) => addGuidToShape(a)) || [],
                annotations: JSON.parse(documentData.Shapes)[2].annotations.map((a) => addGuidToShape(a)) || [],
                highlights: JSON.parse(documentData.Shapes)[1].highlights.map((a) => addGuidToShape(a)) || [],
            }) || {
                redactions: [],
                annotations: [],
                highlights: [],
            },
            pageAttributes: (documentData.PageAttributes && JSON.parse(documentData.PageAttributes)) || [],
        };
    }),
    isPreviewAvailable: ({ document, version, page, abortController }) => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
        return yield repo.preview.available({ document, version, page, abortController });
    }),
    canEditDocument: ({ document, abortController }) => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
        const response = yield repo.security.hasPermission(document.idOrPath, ['Save'], undefined, {
            signal: abortController.signal,
            credentials: 'include',
        });
        return response;
    }),
    canHideRedaction: ({ document, abortController }) => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
        return yield repo.security.hasPermission(document.idOrPath, ['PreviewWithoutRedaction'], undefined, {
            signal: abortController.signal,
            credentials: 'include',
        });
    }),
    canHideWatermark: ({ document, abortController }) => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
        return yield repo.security.hasPermission(document.idOrPath, ['PreviewWithoutWatermark'], undefined, {
            signal: abortController.signal,
            credentials: 'include',
        });
    }),
    getExistingPreviewImages: ({ document, version, abortController }) => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
        return yield repo.preview.getExistingImages({ document, version, abortController });
    }),
    commentActions: {
        addPreviewComment: ({ document, comment, abortController }) => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
            const response = yield repo.preview.addComment({ idOrPath: document.idOrPath, comment, abortController });
            return [response].map(changeCreatedByUrlToCurrent(document))[0];
        }),
        deletePreviewComment: ({ document, commentId, abortController }) => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
            return yield repo.preview.deleteComment({ idOrPath: document.idOrPath, commentId, abortController });
        }),
        getPreviewComments: ({ document, page, abortController }) => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
            const response = yield repo.preview.getComments({ idOrPath: document.idOrPath, page, abortController });
            return response.map(changeCreatedByUrlToCurrent(document));
        }),
    },
});
exports.DocumentViewerApiSettingsProvider = ({ children, options, }) => {
    const repo = hooks_react_1.useRepository();
    const [settings, setSettings] = react_1.useState(client_utils_1.deepMerge(exports.createDefaultApiSettings(repo), options));
    react_1.useEffect(() => {
        setSettings(client_utils_1.deepMerge(exports.createDefaultApiSettings(repo), options));
    }, [repo, options]);
    return (react_1.default.createElement(exports.DocumentViewerApiSettingsContext.Provider, { value: settings }, children));
};
//# sourceMappingURL=api-settings.js.map