"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const client_utils_1 = require("@sensenet/client-utils");
const react_1 = tslib_1.__importStar(require("react"));
const hooks_1 = require("../hooks");
exports.defaultCommentsContext = {
    comments: [],
    addPreviewComment: () => tslib_1.__awaiter(void 0, void 0, void 0, function* () { return undefined; }),
    deletePreviewComment: () => tslib_1.__awaiter(void 0, void 0, void 0, function* () { return undefined; }),
    getPreviewComments: () => tslib_1.__awaiter(void 0, void 0, void 0, function* () { return undefined; }),
};
exports.CommentsContext = react_1.default.createContext(exports.defaultCommentsContext);
exports.CommentsContextProvider = ({ page, children, images }) => {
    const api = hooks_1.useDocumentViewerApi();
    const { documentData } = hooks_1.useDocumentData();
    const viewerState = hooks_1.useViewerState();
    const [comments, setComments] = react_1.useState([]);
    react_1.useEffect(() => {
        const abortController = new AbortController();
        (() => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
            if (viewerState.showComments && images === 'preview') {
                const result = yield api.commentActions.getPreviewComments({ document: documentData, page, abortController });
                setComments(result);
            }
        }))();
        return () => abortController.abort();
    }, [api.commentActions, documentData, images, page, viewerState.showComments]);
    react_1.useEffect(() => {
        const disposables = [
            client_utils_1.Trace.method({
                object: api.commentActions,
                isAsync: true,
                methodName: 'addPreviewComment',
                method: api.commentActions.addPreviewComment,
                onFinished: ({ returned }) => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
                    const a = yield returned;
                    setComments([...comments, a]);
                    viewerState.updateState({ isPlacingCommentMarker: false });
                }),
            }),
            client_utils_1.Trace.method({
                object: api.commentActions,
                method: api.commentActions.deletePreviewComment,
                methodName: 'deletePreviewComment',
                isAsync: true,
                onFinished: ({ returned, methodArguments }) => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
                    const returnedValue = yield returned;
                    if (returnedValue.modified) {
                        setComments(comments.filter((c) => c.id !== methodArguments[0].commentId));
                    }
                }),
            }),
        ];
        return () => disposables.forEach((d) => d.dispose());
    }, [api.commentActions, comments, viewerState]);
    return (react_1.default.createElement(exports.CommentsContext.Provider, { value: Object.assign(Object.assign({}, api.commentActions), { comments }) }, children));
};
//# sourceMappingURL=comments.js.map