"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const react_1 = tslib_1.__importStar(require("react"));
const hooks_1 = require("../hooks");
const services_1 = require("../services");
exports.PreviewImageDataContext = react_1.default.createContext({ imageData: [], rotateImages: () => undefined });
exports.PreviewImageDataContextProvider = (props) => {
    const viewerSettings = hooks_1.useViewerSettings();
    const api = hooks_1.useDocumentViewerApi();
    const { documentData, updateDocumentData } = hooks_1.useDocumentData();
    const viewerState = hooks_1.useViewerState();
    const permissions = hooks_1.useDocumentPermissions();
    const [previewImages, setPreviewImages] = react_1.useState([]);
    react_1.useEffect(() => {
        const abortController = new AbortController();
        (() => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
            try {
                setPreviewImages([]);
                const images = yield api.getExistingPreviewImages({
                    document: documentData,
                    version: viewerSettings.version || '',
                    showWatermark: viewerState.showWatermark,
                    abortController,
                });
                setPreviewImages(images);
            }
            catch (error) {
                if (!abortController.signal.aborted) {
                    throw error;
                }
            }
        }))();
        return () => abortController.abort();
        // eslint-disable-next-line react-hooks/exhaustive-deps
    }, [
        api,
        documentData.idOrPath,
        documentData.hostName,
        viewerSettings.documentIdOrPath,
        viewerSettings.version,
        viewerState.showWatermark,
    ]);
    const rotateImages = react_1.useCallback((imageIndexes, amount) => {
        if (!permissions.canEdit) {
            console.warn(`No permission to edit!`);
            return;
        }
        const newImages = previewImages.map((img) => {
            const newImg = Object.assign({}, img);
            if (imageIndexes.indexOf(newImg.Index) >= 0) {
                const newAngle = services_1.ImageUtil.normalizeDegrees(((newImg.Attributes && newImg.Attributes.degree) || 0) + (amount % 360)) % 360;
                newImg.Attributes = Object.assign(Object.assign({}, newImg.Attributes), { degree: newAngle });
            }
            updateDocumentData({
                shapes: {
                    annotations: services_1.applyShapeRotations(documentData.shapes.annotations, amount, img),
                    highlights: services_1.applyShapeRotations(documentData.shapes.highlights, amount, img),
                    redactions: services_1.applyShapeRotations(documentData.shapes.redactions, amount, img),
                },
            });
            return newImg;
        });
        setPreviewImages(newImages);
        viewerState.updateState({ hasChanges: true });
    }, [documentData, updateDocumentData, permissions.canEdit, previewImages, viewerState]);
    return (react_1.default.createElement(exports.PreviewImageDataContext.Provider, { value: {
            imageData: previewImages,
            rotateImages,
        } }, props.children));
};
//# sourceMappingURL=preview-image-data.js.map