"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const client_utils_1 = require("@sensenet/client-utils");
const react_1 = require("react");
const _1 = require(".");
const POLLING_INTERVAL = 3000;
exports.usePreviewImage = (pageNo) => {
    const images = _1.usePreviewImages();
    const api = _1.useDocumentViewerApi();
    const { documentData } = _1.useDocumentData();
    const viewerSettings = _1.useViewerSettings();
    const viewerState = _1.useViewerState();
    const [previewImage, setPreviewImage] = react_1.useState(images.imageData.find((i) => i.Index === pageNo));
    const _a = Object.assign({}, images), { imageData } = _a, context = tslib_1.__rest(_a, ["imageData"]);
    react_1.useEffect(() => {
        setPreviewImage(images.imageData.find((i) => i.Index === pageNo));
    }, [images.imageData, pageNo]);
    react_1.useEffect(() => {
        const abortController = new AbortController();
        const getPreviewImageData = () => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
            try {
                const previewImageData = yield api.isPreviewAvailable({
                    abortController,
                    document: documentData,
                    page: pageNo,
                    showWatermark: viewerState.showWatermark,
                    version: viewerSettings.version || '',
                });
                if (previewImageData === null || previewImageData === void 0 ? void 0 : previewImageData.PreviewAvailable) {
                    setPreviewImage(previewImageData);
                }
                else {
                    yield client_utils_1.sleepAsync(POLLING_INTERVAL);
                    getPreviewImageData();
                }
            }
            catch (error) {
                if (!abortController.signal.aborted) {
                    throw error;
                }
            }
        });
        if (previewImage && !previewImage.PreviewImageUrl) {
            getPreviewImageData();
        }
        return () => abortController.abort();
    }, [api, documentData, pageNo, previewImage, viewerSettings.version, viewerState.showWatermark]);
    const rotate = react_1.useCallback((amount) => images.rotateImages([pageNo], amount), [images, pageNo]);
    return Object.assign(Object.assign({}, context), { image: previewImage, rotate });
};
//# sourceMappingURL=usePreviewImage.js.map